@@ -13,7 +13,15 @@ def setup_grab(grab_object):
 		hammer_mode=True,
 		hammer_timeouts=((10, 15), (20, 30), (25, 40)))
 
-def get_articles(grab_object, title_path, link_path, source):
+def absolutize_link(link, site_url):
+	if link.startswith("//"):
+		link = "http:" + link
+	elif link.startswith("/"):
+		link = "http://" + site_url + link
+	
+	return link
+
+def get_articles(grab_object, title_path, link_path, source, site_url=""):
 	posts = []
 		
 	post_links = grab_object.css_list(link_path)
@@ -21,7 +29,7 @@ def get_articles(grab_object, title_path, link_path, source):
 	
 	for (title, link) in zip(post_links, post_titles):
 		title = title.text_content()
-		link = link.get("href")
+		link = absolutize_link(link.get("href"), site_url)
 		
 		posts.append(
 			{
